需要资源：服务器、数据库（mysql持久化存储、redis数据缓存）、cdn（用于unity场景资源分发）、oss（用于图片、视频存储）、域名

# 一、账号系统
* 1、账号登陆
* 2、账户角色包括：管理员、布展者。管理员可以管理所有布展者及其发布的展览
#
# 二、展会管理
* 1、布展者可以创建、删除、编辑展览。布展者可以隐藏/显示已发布的展览
* 2、布展者可以控制是否显示开幕式、演播厅、展厅
* 3、布展者创建一个展览后，可以对此展览的所有展位进行编辑，可以上传图片（jpg、png）、视频（MP4）
* 4、布展者编辑已有展览，可对每个展位进行编辑
* 5、记录每个展品点赞、送花、访客留言
#
# 三、管理html页面
* 1、登陆页
* 2、验证码邮件
* 3、管理员页面，布展者列表，邀请布展者
* 4、布展者页面，展览列表
* 5、布展者页面，展览编辑页
#
# 四、服务器数据库数据结构
* 1、用户
```json
{
    "email":"xsxhl@live.com",
    "role":1,
    "display_name":"xxx博物馆"
}
```
* 2、展览
```json
{
    "exhibition_template":"",
    "title":"主标题",
    "subtitle":"副标题",
    "beginTime":1234567,
    "endTime":1234567,
    "likes":123,
    "flowers":123,
    "thumb":"http://xxxxxxx",
    "hidden":true
}
```
* 3、作者
  ```json
  {
    "name":"张三",
    "introduction":"1995年出生于xxx"
  }
  ```
* 3、作品
```json
{
    "id":"12345",
    "w":1,
    "h":1,
    "likes":123,
    "flowers":123,
    "thumb":"http://xxxxxxx"
}
```
* 3、展位
```json
{
    "number":1,
    "w":1,
    "h":1,
    "offset_x":0.1,
    "offset_y":0.1,
    "hidden":true,
    "likes":123,
    "flowers":123,
    "thumb":"http://xxxxxxx"
}
```
* 4、展品购买意向留言
```json
{
    "name":"张三",
    "phone":"123",
    "email":"xsxhl@live.com",
    "price":123
}
```
# 五、服务器-客户端数据
* 1、获取展馆信息
### request 
### method: GET
### host: http://182.92.75.61
### path: /exhibition/detail
### 参数列表
| 参数 | 说明 | 值 |
| :-----| ----: | ----: |
| id | 展览id, int | 1,2.. |
### response
```json
{
    "id":1, // 展览id
    "style": 2, // 1为现代，2为古代
    "title": "主标题",
    "subtitle": "副标题",
    "cover": "https://xxxxx", // 封面图
    "start_time": "2022-05-10T19:51:00+08:00", // 展会开始时间
    "end_time": "2022-05-20T19:51:00+08:00", // 展会结束时间
    "stay_time":3, // 停留时间
    "likes": 123, // 点赞数
    "flowers": 123, // 送花数
    "applauses": 123, // 鼓掌数
    "rooms":[ // 所有开放的场馆
        {
            "number": 1, // 场馆类型编号，1为开幕式，2为展厅，3为演播厅
            "exhibits": [ // 当前场馆内所有展位信息
                {
                    "number": 1, // 展位编号
                    "width": 1.01, // 展品宽度(单位：米)
                    "height": 1.01, // 展品高度(单位：米)
                    "offset_x": 0.1, // 展品横向偏移(单位：米)
                    "offset_y": 0.1, // 展品纵向偏移(单位：米)
                    "url": "https://xxxxx" // 展品图片、视频下载地址
                }
            ]
        },
        {
            "number": 2, // 场馆类型编号，1为开幕式，2为展厅，3为演播厅
            "exhibits": [ // 当前场馆内所有展位信息
                {
                    "number": 1, // 展位编号
                    "width": 1.01, // 展品宽度(单位：米)
                    "height": 1.01, // 展品高度(单位：米)
                    "offset_x": 0.1, // 展品横向偏移(单位：米)
                    "offset_y": 0.1, // 展品纵向偏移(单位：米)
                    "url": "https://xxxxx" // 展品图片、视频下载地址
                }
            ]
        },
        {
            "number": 3, // 场馆类型编号，1为开幕式，2为展厅，3为演播厅
            "exhibits": [ // 当前场馆内所有展位信息
                {
                    "number": 1, // 展位编号
                    "width": 1.01, // 展品宽度(单位：米)
                    "height": 1.01, // 展品高度(单位：米)
                    "offset_x": 0.1, // 展品横向偏移(单位：米)
                    "offset_y": 0.1, // 展品纵向偏移(单位：米)
                    "url": "https://xxxxx" // 展品图片、视频下载地址
                }
            ]
        }
    ]
}
```
# 六、前端接口
* 1、获取总览列表
## request 
### method: GET
### host: http://182.92.75.61
### path: /exhibitions
### 参数列表
| 参数 | 说明 | 值 |
| :-----| ----: | ----: |
| type | 展会分类 | 0全部 1戏剧家 2电影电视家 3音乐家 4美术家 5曲艺家 6舞蹈家 7民间艺术家 8摄影家 9书法家 10文艺评论家 11文艺志愿者 12企业（行业）文联 |
## response
```json
[
    {
        "type":0,
        "all":[ // 当前类型下全部展会（当前页返回固定数量展会，例如：最多10个）
            {
                "id":1, // 展览id
                "style": 2, // 1为现代，2为古代
                "title": "主标题",
                "subtitle": "副标题",
                "cover": "http://xxxxx", // 封面图
                "start_time": "2022-05-10T19:51:00+08:00", // 展会开始时间
                "end_time": "2022-05-20T19:51:00+08:00", // 展会结束时间
                "opening_ceremony_used": false, // 是否使用开幕式
                "exhibition_hall_used": true, // 是否使用展厅
                "studio_used": false, // 是否使用演播厅
                "likes": 123, // 点赞数
                "flowers": 123, // 送花数
                "applauses": 123, // 鼓掌数
            }
        ],
        "fine_works":[ // 当前类型下的精品展会（当前页返回固定数量展会，例如：最多10个）
            {
                // 结构同all
            }
        ],
        "masters":[ // 当前类型下的名家展会（当前页返回固定数量展会，例如：最多10个）
            {
                // 结构同all
            }
        ]
    }
]
```

* 2、点击查看更多
## request 
### method: GET
### host: http://182.92.75.61
### path: /exhibitions/more
### 参数列表
| 参数 | 说明 | 值 |
| :-----| ----: | ----: |
| type | 展会分类 | 0全部 1戏剧家 2电影电视家 3音乐家 4美术家 5曲艺家 6舞蹈家 7民间艺术家 8摄影家 9书法家 10文艺评论家 11文艺志愿者 12企业（行业）文联 |
| filter | 展会精选、名家等过滤 | 0全部 1精品 2名家 |
| state_filter | 展览时效状态过滤 | 0全部 1正在展览 2往期展览 3即将展览 |
| page | 第几页 | 1,2... |
| page_size | 每页展会数量 | 1,2... |
## response
```json
[
    {
        "type":0,
        "filter":0,
        "state_filter": 0,
        "page":1,
        "page_size":10,
        "exhibitions":[ // 当前类型下全部展会（当前页返回固定数量展会，例如：最多10个）
            {
                "id":1, // 展览id
                "style": 2, // 1为现代，2为古代
                "title": "主标题",
                "subtitle": "副标题",
                "cover": "http://xxxxx", // 封面图
                "start_time": "2022-05-10T19:51:00+08:00", // 展会开始时间
                "end_time": "2022-05-20T19:51:00+08:00", // 展会结束时间
                "opening_ceremony_used": false, // 是否使用开幕式
                "exhibition_hall_used": true, // 是否使用展厅
                "studio_used": false, // 是否使用演播厅
                "likes": 123, // 点赞数
                "flowers": 123, // 送花数
                "applauses": 123, // 鼓掌数
            }
        ]
    }
]
```

* 3、展品详情页
## request 
### method: GET
### host: http://182.92.75.61
### path: /exhibit/detail
### 参数列表
| 参数 | 说明 | 值 |
| :-----| ----: | ----: |
| id | 展品id | 1,2.. |
## response
```json
{
    "id":1, // 展品id
    "title":"《Three masks》", // 展品名称
    "author_introduction":"1995年出生于xxx", // 作者介绍
    "audio":"https://xxxxxx", // 展品语音介绍
    "introduction":"1234567", // 展品文字介绍
    "details":[
        {
            "media":"https://xxxxxx",
            "detail":"《Three masks》" // 简介
        }
    ],
    "likes":123, // 展品点赞数
    "flowers":123, // 展品送花数
    "applauses":123 // 展品鼓掌数
}
```

* 4、点赞
## request 
### method: GET
### host: http://182.92.75.61
### path: /exhibit/like
### 参数列表
| 参数 | 说明 | 值 |
| :-----| ----: | ----: |
| id | 展品id | 1,2.. |
## response
```json
{
    "count":123
}
```

* 5、送花
## request 
### method: GET
### host: http://182.92.75.61
### path: /exhibit/send_flower
### 参数列表
| 参数 | 说明 | 值 |
| :-----| ----: | ----: |
| id | 展品id | 1,2.. |
## response
```json
{
    "count":123
}
```

* 6、鼓掌
## request 
### method: GET
### host: http://182.92.75.61
### path: /exhibit/give_applause
### 参数列表
| 参数 | 说明 | 值 |
| :-----| ----: | ----: |
| id | 展品id | 1,2.. |
## response
```json
{
    "count":123
}
```

* 7、购买表单
## request 
### method: POST
### host: http://182.92.75.61
### path: /exhibit/offer
### 参数列表 json
| 参数 | 说明 | 值 |
| :-----| ----: | ----: |
| id | 展品id, int | 1,2.. |
| username | 用户名, string | 张三 |
|  phone | 手机号, string | 185xxx |
| bid | 出价, int | 123 |
## response
```json
{
}
```